# hyperi-pylib

HyperI shared Python library - common types, utilities, and integrations.

## Status

This is a namespace reservation. The initial public release is scheduled
for **CY Q2 2026**. Until then this package is intentionally empty.

See the [repository](https://github.com/hyperi-io/hyperi-pylib) for progress.

## License

FSL-1.1-ALv2 - (c) 2026 HYPERI PTY LIMITED
